Coverage for modules/box__bizhelp/contact/forms.py: 100%

# Coverage for modules/box__bizhelp/contact/forms.py : 100%

## 9 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from flask_wtf import FlaskForm

2 from wtforms import StringField

3 from wtforms import TextAreaField

4 from wtforms.fields import EmailField

5 from wtforms.validators import DataRequired

6

7# from wtforms.validators import Length

8

9

10 class ContactForm(FlaskForm):

11 name = StringField(

12 "Name",

13 [DataRequired()],

14 render_kw={"class": "form-control", "autocomplete": "off"},

15 )

16 email = EmailField(

17 "Email",

18 [DataRequired()],

19 render_kw={"class": "form-control", "autocomplete": "off"},

20 )

21 message = TextAreaField(

22 "Message",

23 [DataRequired()],

24 render_kw={

25 "class": "form-control",

26 "rows": "20",

27 "autocomplete": "off",

28 },

29 )